summaryrefslogtreecommitdiff
path: root/extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php
diff options
context:
space:
mode:
Diffstat (limited to 'extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php')
-rw-r--r--extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php7
1 files changed, 5 insertions, 2 deletions
diff --git a/extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php b/extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php
index d3e4af69..4eba6e40 100644
--- a/extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php
+++ b/extensions/ConfirmEdit/MathCaptcha/MathCaptcha.class.php
@@ -16,8 +16,11 @@ class MathCaptcha extends SimpleCaptcha {
$resultArr['captcha']['question'] = $sum;
}
- /** Produce a nice little form */
- function getForm() {
+ /**
+ * Produce a nice little form
+ * @param OutputPage $out
+ */
+ function getForm( OutputPage $out ) {
list( $sum, $answer ) = $this->pickSum();
$index = $this->storeCaptcha( array( 'answer' => $answer ) );